@@ -18,6 +18,13 @@
 solrAdminApp.controller('SchemaDesignerController', function ($scope, $timeout, $cookies, $window, Constants, SchemaDesigner, Luke) {
   $scope.resetMenu("schema-designer", Constants.IS_ROOT_PAGE);
 
+  $scope.schemas = [];
+  $scope.publishedSchemas = [];
+  $scope.sampleDocIds = [];
+  $scope.sortableFields = [];
+  $scope.hlFields = [];
+  $scope.types = [];
+
   $scope.onWarning = function (warnMsg, warnDetails) {
     $scope.updateWorking = false;
     delete $scope.updateStatusMessage;
@@ -251,7 +258,7 @@ solrAdminApp.controller('SchemaDesignerController', function ($scope, $timeout,
           $scope.sampleMessage = "Please upload or paste some sample documents to build the '" + $scope.currentSchema + "' schema.";
         }
       }
-    });
+    }, $scope.errorHandler);
   };
 
   $scope.showNewSchemaDialog = function () {
@@ -437,6 +444,8 @@ solrAdminApp.controller('SchemaDesignerController', function ($scope, $timeout,
 
     if (data.docIds) {
       $scope.sampleDocIds = data.docIds;
+    } else {
+      $scope.sampleDocIds = [];
     }
 
     // Load the Luke schema
@@ -742,7 +751,7 @@ solrAdminApp.controller('SchemaDesignerController', function ($scope, $timeout,
 
       $scope.schemaDiffExists = !(diff.fields == null && diff.fieldTypes == null && dynamicFields == null && diff.copyFields == null);
       $scope.showDiff = true;
-    });
+    }, $scope.errorHandler);
   }
 
   $scope.togglePublish = function (event) {
@@ -840,7 +849,7 @@ solrAdminApp.controller('SchemaDesignerController', function ($scope, $timeout,
       if (data.analysis && data.analysis["field_names"]) {
         $scope.result = processFieldAnalysisData(data.analysis["field_names"][field]);
       }
-    });
+    }, $scope.errorHandler);
   };
 
   $scope.changeLanguages = function () {
@@ -906,7 +915,7 @@ solrAdminApp.controller('SchemaDesignerController', function ($scope, $timeout,
         $scope.showAnalysis = false;
         $scope.selectNodeInTree(id);
       }
-    });
+    }, $scope.errorHandler);
   };
   
   function fieldNodes(src, type) {
@@ -1840,7 +1849,7 @@ solrAdminApp.controller('SchemaDesignerController', function ($scope, $timeout,
         }
       }
       $scope.onSelectQueryResultsNode(nodeId);
-    });
+    }, $scope.errorHandler);
   };
 
   $scope.toggleShowAnalysisJson = function () {
